@@ -1,30 +1,31 @@
 ######################################################################
 # exdate.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# exdate Plugin
+# $Id: exdate.inc.pl,v 1.234 2012/01/30 15:16:26 papu Exp $
 #
-# $Id: exdate.inc.pl,v 1.24 2010/11/27 02:33:38 papu Exp $
-#
-# "exdate.inc.cgi" version 1.03 $$
-# Copyright (C) 2010 by Nanami.
-# Copyright (C) 2010 PyukiWiki Developers Team
-# License: GPL v2 or (at your option) any later version
+# "exdate" version 1.05 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
+# Based on YukiWiki http://www.hyuki.com/yukiwiki/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
+# This program is free software; you can redistribute it and/or
+# modify it under the same terms as Perl itself.
+# Return:LF Code=EUC-JP 1TAB=4Spaces
+######################################################################
+# Based on ߤΥڡ http://koyomi8.com/
+# Based on ׻饤֥ http://www3.biwako.ne.jp/~nobuaki/qreki/
+######################################################################
+# This is extented plugin.
+# To use this plugin, rename to 'exdate.inc.cgi'
+######################################################################
 # Based on ߤΥڡ http://koyomi8.com/
 # Based on ׻饤֥ http://www3.biwako.ne.jp/~nobuaki/qreki/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-#
-# 1TAB=4Spaces
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl itself.
-# Return Code:LF
-# Japanese Code=EUC
-######################################################################
-# This is extented plugin.
-# To use this plugin, rename to 'exdate.inc.cgi'
 ######################################################################
 #    :SG:///ʿ Sg:///ʿ
 #         SA:M/T/S/H Sa:///
@@ -99,15 +100,18 @@
 #         QKj:󽽡/QKJ:졻
 ######################################################################
 # ʲwiki.cgiƱ
-# t ꤷ 28  31 
+# t ꤷ 28  31
 # O   : ˥åȤλֺ
-# r RFC 822 եޥåȤ줿 : Thu, 21 Dec 2000 16:01:07 +0200 
-# Z ॾΥեåÿ -43200  43200 
-# L ǯǤ뤫ɤɽ͡ 1ʤ鱼ǯ0ʤ鱼ǯǤϤʤ 
-# B Swatch 󥿡ͥåȻ 000  999 
-# U Unix (1970ǯ1100ʬ0)ÿ See also time() 
+# r RFC 822 եޥåȤ줿 : Thu, 21 Dec 2000 16:01:07 +0200
+# Z ॾΥեåÿ -43200  43200
+# L ǯǤ뤫ɤɽ͡ 1ʤ鱼ǯ0ʤ鱼ǯǤϤʤ
+# B Swatch 󥿡ͥåȻ 000  999
+# U Unix (1970ǯ1100ʬ0)ÿ See also time()
 ######################################################################
 
+$EXPLUGIN="exdate";
+$VERSION="1.05";
+
 # ĿѹԻ
 @EXDATE::MY_GYOJI=(
 #	"1900-/1/1:",	# example
@@ -116,10 +120,10 @@
 
 # ꥹ Ť ǯ//:̾:Ⱦʸʸ
 @EXDATE::GANGO=(
-	"1868/9/8::M",	# ɬפʤפʸ򥳥ȥȤ
-	"1912/7/30::T",	# ڤʤޤ
-	"1926/12/25::S",
-	"1989/1/8:ʿ:H"
+	"1868/9/8:::M",	# ɬפʤפʸ򥳥ȥȤ
+	"1912/7/30:::T",	# ڤʤޤ
+	"1926/12/25:::S",
+	"1989/1/8:ʿ:ʿ:H"
 );
 
 # 񥭥åκ¸
@@ -404,18 +408,19 @@ sub get_gango {
 	my $gshort="";
 	my $gyear="";
 	foreach(@EXDATE::GANGO) {
-		my($mymd,$mgango,$mshort)=split(/:/,$_);
+		my($mymd,$mgango,$mgango2,$mshort)=split(/:/,$_);
 		my($my,$mm,$md)=split(/\//,$mymd);
 		if(		$year+0>$my+0
 				|| ($mon > $mm+0 && $year+0 eq $my+0)
 				|| ($mday+0 >= $md+0 && $mon eq $mm+0 && $year+0 eq $my+0)
 			) {
 			$gango=$mgango;
+			$gango2=$mgango2;
 			$gshort=$mshort;
 			$gyear=$year-$my+1;
 		}
 	}
-	return($gango,$gshort,$gyear);
+	return($gango,$gango2,$gshort,$gyear);
 }
 
 # 1­
@@ -776,7 +781,14 @@ sub h2z() {
 	}
 	$zen='ɡǡʡˡܡݡ䡩£ãģţƣǣȣɣʣˣ̣ͣΣϣУѣңӣԣգ֣ףأ٣ڡΡϡƣСá';
 	$han='!"#$%&\'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}';
-	$buf=Jcode->new($parm)->h2z->tr($han,$zen);
+	if($::defaultcode eq 'euc') {
+		$buf=Jcode->new($parm)->h2z->tr($han,$zen);
+	} else {
+$buf='';
+		$zen=Jcode->new($zen,'utf8')->euc;
+		$parm=Jcode->new($parm,'utf8')->euc;
+		$buf=Jcode->new($parm)->h2z->tr($han,$zen)->utf8;
+	}
 	$::EXDATE_CACHE->write("h2z-$parm","$buf\n");
 	return $buf;
 }
@@ -855,9 +867,9 @@ sub ex_date1 {
 	if($format=~m/N(\d{1,2})(SG|Sg|Sa|SY|Sy|GY|XY|Xy)/g) {
 		my $tmp=$1;
 		$nendo=$year-($mon < $tmp ? 1 : 0);
-		my($_gango,$_gshort,$_gyear)=&get_gango($nendo,$1,1);
+		my($_gango,$_gango2,$_gshort,$_gyear)=&get_gango($nendo,$1,1);
 		$format=~s/N$tmp\SG/$_gango/ge;					# ʿ
-		$format=~s/N$tmp\Sg/substr($_gango,0,2)/ge;		# ʿ
+		$format=~s/N$tmp\Sg/$_gango2/ge;		# ʿ
 		$format=~s/N$tmp\Sa/&h2z($_gshort)/ge;			# 
 		$format=~s/N$tmp\GY/($_gyear eq 1 ? '' : &h2z($_gyear))/ge;	# 
 		$format=~s/N$tmp\XY/&itoa_ja($_gyear,1,1)/ge;	# 
@@ -867,9 +879,9 @@ sub ex_date1 {
 	}
 	# 
 	if($format=~m/(SG|Sg|Sa|SY|Sy|GY|XY|Xy)/g) {
-		my($_gango,$_gshort,$_gyear)=&get_gango($year,$mon,$mday);
+		my($_gango,$_gango2,$_gshort,$_gyear)=&get_gango($year,$mon,$mday);
 		$format=~s/SG/$_gango/ge;						# ʿ
-		$format=~s/Sg/substr($_gango,0,2)/ge;			# ʿ
+		$format=~s/Sg/$_gango2/ge;						# ʿ
 		$format=~s/Sa/&h2z($_gshort)/ge;				# 
 		$format=~s/GY/($_gyear eq 1 ? '' : &h2z($_gyear))/ge;	# 
 		$format=~s/XY/&itoa_ja($_gyear,1,1)/ge;			# 
@@ -936,7 +948,7 @@ sub ex_date2 {
 	# 
 	if($format=~m/\x11\x11/g) {
 		$nendo=$year-($mon < $tmp ? 1 : 0);
-		my($_gango,$_gshort,$_gyear)=&get_gango($year,$mon,$mday);
+		my($_gango,$_gango2,$_gshort,$_gyear)=&get_gango($year,$mon,$mday);
 		$format=~s/\x11\x11/$_gshort/ge;				# H
 	}
 	# 
@@ -1002,6 +1014,33 @@ sub ex_date2 {
 # ʲС饤ɤؿ
 #
 
+sub dateinit {
+	my $i=0;
+	foreach(split(/,/,$::resource{"date_ampm_en"})) {
+		$::_date_ampm[$i++]=$_;
+	}
+	$i=0;
+	foreach(split(/,/,$::resource{"date_ampm_".$::lang})) {
+		$::_date_ampm_locale[$i++]=$_;
+	}
+	$i=0;
+	foreach(split(/,/,$::resource{"date_weekday_en"})) {
+		$::_date_weekday[$i++]=$_;
+	}
+	$i=0;
+	foreach(split(/,/,$::resource{"date_weekday_".$::lang})) {
+		$::_date_weekday_locale[$i++]=$_;
+	}
+	$i=0;
+	foreach(split(/,/,$::resource{"date_weekday_en_short"})) {
+		$::_date_weekday_short[$i++]=$_;
+	}
+	$i=0;
+	foreach(split(/,/,$::resource{"date_weekday_".$::lang."_short"})) {
+		$::_date_weekday_locale_short[$i++]=$_;
+	}
+}
+
 sub date {
 	my ($format, $tm, $gmtime) = @_;
 	my %weekday;
@@ -1011,7 +1050,7 @@ sub date {
 	my ($_year,$_mon);
 
 	# yday:0-365 $isdst Summertime:1/not:0
-	my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = 
+	my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) =
 		$gmtime ne '' && @_ > 2
 			? ($tm+0 > 0 ? gmtime($tm) : gmtime(time))
 			: ($tm+0 > 0 ? localtime($tm) : localtime(time));
@@ -1021,15 +1060,15 @@ sub date {
 
 	$format=&ex_date1($format,$sec,$min,$hour,$hr12,$mday,$mon+1,$year,$wday,$yday,$isdst);
 
-	# am / pm strings
-	$ampm{en}=$hour>11 ? 'pm' : 'am';
-	$ampm{ja}=$hour>11 ? '' : '';
+	# am / pm strings										# comment
+	$ampm{en}=$::_date_ampm[$hour>11 ? 1 : 0];
+	$ampm{$::lang}=$::_date_ampm_locale[$hour>11 ? 1 : 0];
 
-	# weekday strings
-	$weekday{en} = ('Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday')[$wday];
-	$weekday{en}{length}=3;
-	$weekday{ja} = ('', '', '', '', '', '', '')[$wday];
-	$weekday{ja}{length}=2;
+	# weekday strings										# comment
+	$weekday{en}=$::_date_weekday[$wday];
+	$weekday{en_short}=$::_date_weekday_short[$wday];
+	$weekday{$::lang}=$::_date_weekday_locale[$wday];
+	$weekday{$::lang."_short"}=$::_date_weekday_locale_short[$wday];
 
 	$weekday_lang=$weekday{$::lang} eq '' ? 'en' : $::lang;
 	$ampm_lang=$ampm{$::lang} eq '' ? 'en' : $::lang;
@@ -1115,37 +1154,36 @@ sub date {
 
 	$format =~ s/I/$isdst/g;	# I(Upper i):1 Summertime/0:Not
 
-	$format =~ s/\x1\x11/$ampm{en}/g;			# a:am or pm
-	$format =~ s/\x1\x12/uc $ampm{en}/eg;		# A:AM or PM
-	$format =~ s/\x1\x13/$ampm{$ampm_lang}/g;	# A: or 
-	$format =~ s/\x1\x14/uc $ampm{$ampm_lang}/eg;# ʸ
+	$format =~ s/\x1\x12/uc $ampm{en}/ge;		# A:AM or PM		# comment
+	$format =~ s/\x1\x13/$ampm{$::lang}/ge;		# A: or 	# comment
+	$format =~ s/\x1\x14/uc $ampm{$::lang}/ge;	# ʸ		# comment
 
-	$format =~ s/\x2\x11/$weekday{en}/g;		# l(lower L):Sunday-Saturday
-	$format =~ s/\x2\x12/substr($weekday{en},0,$weekday{en}{length})/ge;	# D:Mon-Sun
-	$format =~ s/\x2\x13/substr($weekday{$weekday_lang},0,$weekday{$weekday_lang}{length})/ge;	# D:Mon-Sun
-	$format =~ s/\x2\x14/$weekday{$weekday_lang}/g;
+	$format =~ s/\x2\x11/$weekday{en}/ge;		# l(lower L):Sunday-Saturday	# comment
+	$format =~ s/\x2\x12/$weekday{en_short}/ge;	# D:Mon-Sun	# comment
+	$format =~ s/\x2\x13/$weekday{"$::lang" . "_short"}/ge;	# D:Mon-Sun	# comment
+	$format =~ s/\x2\x14/$weekday{$::lang}/ge;
 
 	$format =~ s/\x3\x11/substr($month,0,3)/ge;	# M:Jan-Dec
 	$format =~ s/\x3\x12/$month/g;				# F:January-December
 
 	# v0.1.6Ǽ
-	# O ˥åɸ(GMT)Ȥλֺ Example: +0200 
-	# r RFC 822 եޥåȤ줿 : Thu, 21 Dec 2000 16:01:07 +0200 
-	# Z ॾΥեåÿ -43200  43200 
-	# L ǯǤ뤫ɤɽ͡ 1ʤ鱼ǯ0ʤ鱼ǯǤϤʤ 
+	# O ˥åɸ(GMT)Ȥλֺ Example: +0200
+	# r RFC 822 եޥåȤ줿 : Thu, 21 Dec 2000 16:01:07 +0200
+	# Z ॾΥեåÿ -43200  43200
+	# L ǯǤ뤫ɤɽ͡ 1ʤ鱼ǯ0ʤ鱼ǯǤϤʤ
 	# lL:ߤΥθǤû
 	# DL:ߤΥθǤĹ
 	# aL:ߤΥθǤθʸ
 	# AL:ߤΥθǤθʾʸ
-	# L ǯǤ뤫ɤɽ͡ 1ʤ鱼ǯ0ʤ鱼ǯǤϤʤ 
-	# t ꤷ 28  31 
-	# B Swatch 󥿡ͥåȻ 000  999 
-	# U Unix (1970ǯ1100ʬ0)ÿ See also time() 
+	# L ǯǤ뤫ɤɽ͡ 1ʤ鱼ǯ0ʤ鱼ǯǤϤʤ
+	# t ꤷ 28  31
+	# B Swatch 󥿡ͥåȻ 000  999
+	# U Unix (1970ǯ1100ʬ0)ÿ See also time()
 
 	# Not Allowed
-	# W ISO-8601 ˻Ϥޤǯñ̤νֹ (PHP 4.1.0ɲ) : 42 (ǯ42) 
-	# S Ѹνɽեå2 ʸ st, nd, rd or th. Works well with j  
-	# T ΥޥΥॾꡣ Examples: EST, MDT ... 
+	# W ISO-8601 ˻Ϥޤǯñ̤νֹ (PHP 4.1.0ɲ) : 42 (ǯ42)
+	# S Ѹνɽեå2 ʸ st, nd, rd or th. Works well with j
+	# T ΥޥΥॾꡣ Examples: EST, MDT ...
 	$format =~ s/z/$yday/ge;	# z:days/year 0-366
 
 	$format=&ex_date2($format,$sec,$min,$hour,$hr12,$mday,$mon,$year,$wday,$yday,$isdst);
@@ -1159,7 +1197,7 @@ sub plugin_exdate_setup {
 	'en'=>'Extended view date format',
 	'use_req'=>'Jcode,Nana::Cache',
 	'override'=>'date',
-	'url'=>'http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Nanami/exdate/'
+	'url'=>'http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Nanami/exdate/'
 	);
 __END__
 
@@ -1191,13 +1229,17 @@ date function was overrided.
 
 =item PyukiWiki/Plugin/Nanami/exdate
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Nanami/exdate/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Nanami/exdate/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/exdate.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/exdate.inc.pl?view=log>
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/exdate-qreki.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/lib/exdate.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/exdate-qreki.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/lib/exdate-qreki.inc.pl?view=log>
 
 =back
 
@@ -1209,19 +1251,20 @@ L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/exdate-qreki.inc.
 
 L<http://nanakochi.daiba.cx/> etc...
 
+
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2010 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2010 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
